<?php

/**
 * @file nodereference_explorer.views.inc
 * Class responsible for widget and dialog initialization
 */
class nodereference_explorer_views {

  public $ids; //widget element ids (associative array)
  public $options; //options for dialog, content and theming (associative array)

  private $field; //referenced field
  private $view_name; //name of the referenced view
  private $view_args; //relevant view arguments

  /**
   * Initialize the handler (ids, options, field)
   * @param $field cck field
   */
  public function __construct($field) {
    $this->field  = $field;
    $this->ids = array();
    $this->options = array();

    //determine view name
    if (empty($this->field['advanced_view']) || $this->field['advanced_view'] == '--') {//default view
      //pretend the field to be a view (for function _nodereference_potential_references())
      $this->field['advanced_view'] = NODE_REFERENCE_EXPLORER_DEFAULT_VIEW_NAME;
      $this->view_name = NODE_REFERENCE_EXPLORER_DEFAULT_VIEW_NAME;
    }
    else {
      $this->view_name = $this->field['advanced_view'];
    }

    // Get arguments for the view.
    if (!empty($this->field['advanced_view_args'])) {
      $this->view_args = array_map('trim', explode(',', $this->field['advanced_view_args']));

    }
    else {
      $this->view_args = array();
    }
  }

  /**
   * Get a specific view item by node ids
   * @param $nid node id
   * @return rendered view item
   */
  public function get_item($nid) {
    $match = isset($this->field['widget']['autocomplete_match']) ? $this->field['widget']['autocomplete_match'] : 'contains';
    $references = _nodereference_potential_references($this->field, '', $match, array(), 100);
	return $references[$nid]['rendered'];
  }

  /**
   * Get a filter form for a display
   * @param $display_id display identifier
   * @return rendered filter form
   */
  public function get_exposed_form($display_id) {
    if (($view = views_get_view($this->view_name)) != NULL) { //get view by name
      $view->set_display($display_id);
      $view->init_handlers(); //initialize display handlers
      $form_state = array(
      	'view' => $view,
      	'display' => $view->display_handler->display,
      	'method' => 'get',
      	'rerender' => TRUE,
      	'no_redirect' => TRUE,
      );
      $form = drupal_build_form('views_exposed_form', $form_state); //create the filter form
      return $form;
    }
    else {
      return NULL;
    }
  }

  /**
   * Get all available displays of the assigend
   * view.
   * @return array of display objects
   */
  public function get_all_displays() {
    if (($view = views_get_view($this->view_name)) != NULL) { //get view by name
      $displays = $view->display; //get all available displays
      //array_shift($displays);
      return $displays;
    }
    else {
      return NULL;
    }
  }

  /**
   * Get the initial display id. This
   * is not the default display which
   * is omitted.
   * @return id of the display
   */
  public function get_first_display() {
    foreach ($this->get_all_displays() as $display) {
      if ($display->id != 'default') {
        $id = $display->id;
        return $id;
      }
    }
  return NULL;
  }

  /**
   * Get a display by id.
   * @param $display_id display identifier
   * @return rendered display
   */
  public function get_display($display_id) {

   if (($view = views_get_view($this->view_name)) != NULL) { //get view by name
     $view->set_display($display_id); //set display, e. g. thumbnails or table
     $output = $view->execute_display($display_id, $this->view_args); //render the display
     if ($display_id == 'default') {//hide default view
       $output = '<div style="display:none">' . $output . '</div>';
     }
     if (!is_array($output)) //return rendered output for pages
       return $output;
     else { //if an array then output rendered for blocks
       return $output['content'];
     }
   }
   else { //no view with this name (should not happen)
     return NULL;
   }
  }

  /**
   * Determine if the widget should show a preview
   * below the autocomplete field.
   * @return boolean if preview should be shown
   */
  public function is_show_preview() {
    //look at widget settings
    return $this->field['widget']['content_preview'] == '1' ? TRUE : FALSE;
  }

  /**
   * Set an unique identifier and value.
   * @param $key identifier
   * @param $value value
   */
  public function set_id($key, $value) {
    if (!isset($this->ids[$key]) ||
        !is_array($this->ids[$key])) {
          $this->ids[$key] = array();
        }
    array_push($this->ids[$key], $value);
  }

  /**
   * Get an id value
   * @param $key identifier
   * @param $index number of the widget (multiple values)
   * @return id value
   */
  public function get_id($key, $index) {
    if (isset($this->ids[$key]))
      return $this->ids[$key][$index];
    else {
      return NULL;
    }
  }

  /**
   * Set options for the widget (dialog, actions, theme...)
   * @param $key identifier
   * @param $value value
   */
  public function set_options($key, $value) {
    $this->options[$key] = $value;
  }

  /**
   * Retrieve options for the widget
   * @param $key identifier
   * @return $value value
   */
  public function get_options($key) {
    if (isset($this->options[$key]))
      return $this->options[$key];
    else {
      return NULL;
    }
  }

}